package de.intevation.gnv.utils;

import de.intevation.artifacts.ArtifactFactory;

import org.apache.log4j.Logger;

import org.w3c.dom.Document;
import org.w3c.dom.Node;

/**
 * @author Tim Englich <tim.englich@intevation.de>
 *
 */
public class ArtifactFactoryUtilities {
    /**
     * the logger, used to log exceptions and additonaly information
     */
    private static Logger log = Logger
            .getLogger(ArtifactFactoryUtilities.class);

    /**
     * Constructor
     */
    public ArtifactFactoryUtilities() {
    }

    public ArtifactFactory createArtitfactFactor(Document config,
                                                 Node artifactFactoryNode) {
        String className = artifactFactoryNode.getTextContent();

        ArtifactFactory factory = null;

        try {
            Class clazz = Class.forName(className);
            factory = (ArtifactFactory) clazz.newInstance();
        } catch (ClassNotFoundException cnfe) {
            log.error(cnfe.getLocalizedMessage(), cnfe);
        } catch (InstantiationException ie) {
            log.error(ie.getLocalizedMessage(), ie);
        } catch (ClassCastException cce) {
            log.error(cce.getLocalizedMessage(), cce);
        } catch (IllegalAccessException iae) {
            log.error(iae.getLocalizedMessage(), iae);
        }

        if (factory != null) {
            factory.setup(config, artifactFactoryNode);
            log.info("Registering '" + factory.getName()
                     + "' as artifact factory.");
        }
        return factory;
    }
}
